@@ -1,7 +1,6 @@
 import os
 from typing import Optional
 
-# @ todo remove this dependencies on grimoire
 from python_search.apps.notification_ui import send_notification
 from python_search.apps.terminal import Terminal
 from python_search.context import Context
@@ -50,12 +49,6 @@ class CmdInterpreter(BaseInterpreter):
 
         cmd = self.apply_directory(self.cmd["cmd"])
 
-        if "high_priority" in self.cmd:
-            cmd = f"nice -19 {cmd}"
-
-        if "directory" in self.cmd:
-            cmd = f'cd {self.cmd["directory"]} && {cmd}'
-
         cmd = self._try_to_wrap_in_terminal(cmd)
 
         logger.info(f"Command to run: {cmd}")
